Module: MTrack::Core

Defined in:
lib/mtrack/core.rb

Overview

Implements the core tracking functionality of the gem by extending those Modules and Classes that use MTrack::ModuleMixin#track_methods. Additionally it will extend Modules and Classes that include a Module that is tracking methods and Classes that inherit from a Class that is tracking methods.

Instance Method Summary collapse

Instance Method Details

#tracked_methods(group_name = nil) ⇒ Object

call-seq:

tracked_methods(group_name = nil) => set

Returns a set containing the currently tracked methods for a group_name.

class C
  track_methods :my_group do
    def method_1; end
    def method_2; end
  end
end

C.tracked_methods :my_group  #=> #<Set: {:method_1, :method_2}>


35
36
37
# File 'lib/mtrack/core.rb', line 35

def tracked_methods(group_name = nil)
  @__mtrack__.tracked group_name
end