Module: MTrack::Mixin
- Extended by:
- Extension
- Defined in:
- lib/mtrack/mixin.rb
Overview
This module provides the #track_methods method to Classes or Modules that extend it. It also enables the extended Class or Module to pass tracked methods to its subclasses and submodules.
Instance Method Summary collapse
-
#tracked_methods(group_name = nil) ⇒ Object
call-seq: tracked_methods(group_name = nil) => set.
Instance Method Details
#tracked_methods(group_name = nil) ⇒ Object
94 95 96 |
# File 'lib/mtrack/mixin.rb', line 94 def tracked_methods(group_name = nil) @__mtrack__.tracked group_name end |